@@ -23,7 +23,7 @@ from aliyunsdkcloudesl.endpoint import endpoint_data
 class BatchInsertItemsRequest(RpcRequest):
 
 	def __init__(self):
-		RpcRequest.__init__(self, 'cloudesl', '2020-02-01', 'BatchInsertItems','cloudesl')
+		RpcRequest.__init__(self, 'cloudesl', '2020-02-01', 'BatchInsertItems')
 		self.set_method('POST')
 		if hasattr(self, "endpoint_map"):
 			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
@@ -78,16 +78,22 @@ class BatchInsertItemsRequest(RpcRequest):
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureL', ItemInfos[depth1].get('CustomizeFeatureL'))
 			if ItemInfos[depth1].get('CustomizeFeatureM') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureM', ItemInfos[depth1].get('CustomizeFeatureM'))
-			if ItemInfos[depth1].get('BePromotion') is not None:
-				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.BePromotion', ItemInfos[depth1].get('BePromotion'))
 			if ItemInfos[depth1].get('CustomizeFeatureN') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureN', ItemInfos[depth1].get('CustomizeFeatureN'))
+			if ItemInfos[depth1].get('BePromotion') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.BePromotion', ItemInfos[depth1].get('BePromotion'))
 			if ItemInfos[depth1].get('CustomizeFeatureO') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureO', ItemInfos[depth1].get('CustomizeFeatureO'))
+			if ItemInfos[depth1].get('CustomizeFeatureP') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureP', ItemInfos[depth1].get('CustomizeFeatureP'))
 			if ItemInfos[depth1].get('PromotionEnd') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.PromotionEnd', ItemInfos[depth1].get('PromotionEnd'))
 			if ItemInfos[depth1].get('ItemTitle') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemTitle', ItemInfos[depth1].get('ItemTitle'))
+			if ItemInfos[depth1].get('CustomizeFeatureQ') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureQ', ItemInfos[depth1].get('CustomizeFeatureQ'))
+			if ItemInfos[depth1].get('CustomizeFeatureR') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureR', ItemInfos[depth1].get('CustomizeFeatureR'))
 			if ItemInfos[depth1].get('CustomizeFeatureC') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureC', ItemInfos[depth1].get('CustomizeFeatureC'))
 			if ItemInfos[depth1].get('CustomizeFeatureD') is not None:
@@ -96,10 +102,10 @@ class BatchInsertItemsRequest(RpcRequest):
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemQrCode', ItemInfos[depth1].get('ItemQrCode'))
 			if ItemInfos[depth1].get('CustomizeFeatureE') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureE', ItemInfos[depth1].get('CustomizeFeatureE'))
-			if ItemInfos[depth1].get('InventoryStatus') is not None:
-				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.InventoryStatus', ItemInfos[depth1].get('InventoryStatus'))
 			if ItemInfos[depth1].get('PromotionReason') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.PromotionReason', ItemInfos[depth1].get('PromotionReason'))
+			if ItemInfos[depth1].get('InventoryStatus') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.InventoryStatus', ItemInfos[depth1].get('InventoryStatus'))
 			if ItemInfos[depth1].get('CustomizeFeatureF') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureF', ItemInfos[depth1].get('CustomizeFeatureF'))
 			if ItemInfos[depth1].get('CustomizeFeatureG') is not None:
@@ -120,26 +126,42 @@ class BatchInsertItemsRequest(RpcRequest):
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ForestFirstId', ItemInfos[depth1].get('ForestFirstId'))
 			if ItemInfos[depth1].get('ProductionPlace') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ProductionPlace', ItemInfos[depth1].get('ProductionPlace'))
-			if ItemInfos[depth1].get('Manufacturer') is not None:
-				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.Manufacturer', ItemInfos[depth1].get('Manufacturer'))
 			if ItemInfos[depth1].get('SourceCode') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.SourceCode', ItemInfos[depth1].get('SourceCode'))
+			if ItemInfos[depth1].get('Manufacturer') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.Manufacturer', ItemInfos[depth1].get('Manufacturer'))
 			if ItemInfos[depth1].get('ItemId') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemId', ItemInfos[depth1].get('ItemId'))
 			if ItemInfos[depth1].get('BeMember') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.BeMember', ItemInfos[depth1].get('BeMember'))
+			if ItemInfos[depth1].get('CustomizeFeatureS') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureS', ItemInfos[depth1].get('CustomizeFeatureS'))
+			if ItemInfos[depth1].get('CustomizeFeatureT') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureT', ItemInfos[depth1].get('CustomizeFeatureT'))
+			if ItemInfos[depth1].get('CustomizeFeatureU') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureU', ItemInfos[depth1].get('CustomizeFeatureU'))
 			if ItemInfos[depth1].get('TemplateSceneId') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.TemplateSceneId', ItemInfos[depth1].get('TemplateSceneId'))
+			if ItemInfos[depth1].get('CustomizeFeatureV') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureV', ItemInfos[depth1].get('CustomizeFeatureV'))
+			if ItemInfos[depth1].get('CustomizeFeatureW') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureW', ItemInfos[depth1].get('CustomizeFeatureW'))
+			if ItemInfos[depth1].get('CustomizeFeatureX') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureX', ItemInfos[depth1].get('CustomizeFeatureX'))
+			if ItemInfos[depth1].get('CustomizeFeatureY') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureY', ItemInfos[depth1].get('CustomizeFeatureY'))
+			if ItemInfos[depth1].get('CustomizeFeatureZ') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.CustomizeFeatureZ', ItemInfos[depth1].get('CustomizeFeatureZ'))
 			if ItemInfos[depth1].get('SalesPrice') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.SalesPrice', ItemInfos[depth1].get('SalesPrice'))
 			if ItemInfos[depth1].get('OriginalPrice') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.OriginalPrice', ItemInfos[depth1].get('OriginalPrice'))
 			if ItemInfos[depth1].get('ItemShortTitle') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemShortTitle', ItemInfos[depth1].get('ItemShortTitle'))
-			if ItemInfos[depth1].get('ForestSecondId') is not None:
-				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ForestSecondId', ItemInfos[depth1].get('ForestSecondId'))
 			if ItemInfos[depth1].get('ItemPicUrl') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ItemPicUrl', ItemInfos[depth1].get('ItemPicUrl'))
+			if ItemInfos[depth1].get('ForestSecondId') is not None:
+				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.ForestSecondId', ItemInfos[depth1].get('ForestSecondId'))
 			if ItemInfos[depth1].get('SupplierName') is not None:
 				self.add_body_params('ItemInfo.' + str(depth1 + 1) + '.SupplierName', ItemInfos[depth1].get('SupplierName'))
 			if ItemInfos[depth1].get('Material') is not None:
